DOCRELEASE=8.0.5

DGDIR?=/usr/share/pve-doc-generator

ASCIIDOC_PVE?=/usr/bin/asciidoc-pve

PERL_DOC_ENV=PVE_GENERATING_DOCS=1
PERL_DOC_INC_DIRS:=${PERL_DOC_INC_DIRS} .
PERL_DOC_INC=$(foreach dir,${PERL_DOC_INC_DIRS},-I${dir})

PVE_COMMON_DOC_SOURCES=                 \
	${ASCIIDOC_PVE}			\
	pve-copyright.adoc              \
	docinfo.xml

all:

attributes.txt docinfo.xml pmxcfs.8-synopsis.adoc qmeventd.8-synopsis.adoc:
	cp ${DGDIR}/$@ $@.tmp
	mv $@.tmp $@

%-opts.adoc: ${DGDIR}/gen-%-opts.pl
	$(PERL_DOC_ENV) perl ${PERL_DOC_INC} ${DGDIR}/gen-$*-opts.pl >$@.tmp
	mv $@.tmp $@

%.adoc: ${DGDIR}/gen-%-adoc.pl
	$(PERL_DOC_ENV) perl ${PERL_DOC_INC} ${DGDIR}/gen-$*-adoc.pl >$@.tmp
	mv $@.tmp $@

pveperf.1-synopsis.adoc:
	echo '*pveperf* `[PATH]`' > pveperf.1-synopsis.adoc

%.1-synopsis.adoc:
	$(PERL_DOC_ENV) perl ${PERL_DOC_INC} -e "use PVE::CLI::$(subst -,_,$*);print PVE::CLI::$(subst -,_,$*)->generate_asciidoc_synopsis();" > $@.tmp
	mv $@.tmp $@

%.8-synopsis.adoc:
	$(PERL_DOC_ENV) perl ${PERL_DOC_INC} -e "use PVE::Service::$(subst -,_,$*);print PVE::Service::$(subst -,_,$*)->generate_asciidoc_synopsis();" > $@.tmp
	mv $@.tmp $@

ifneq (${DGDIR},.)
%.adoc: ${DGDIR}/%.adoc
	cp $< $@.tmp
	mv $@.tmp $@
endif

%.service-bash-completion:
	perl ${PERL_DOC_INC} -T -e "use PVE::Service::$*; PVE::Service::$*->generate_bash_completions();" >$@.tmp
	mv $@.tmp $@

%.bash-completion:
	perl ${PERL_DOC_INC} -T -e "use PVE::CLI::$*; PVE::CLI::$*->generate_bash_completions();" >$@.tmp
	mv $@.tmp $@

%.service-zsh-completion:
	perl ${PERL_DOC_INC} -T -e "use PVE::Service::$*; PVE::Service::$*->generate_zsh_completions();" >$@.tmp
	mv $@.tmp $@

%.zsh-completion:
	perl ${PERL_DOC_INC} -T -e "use PVE::CLI::$*; PVE::CLI::$*->generate_zsh_completions();" >$@.tmp
	mv $@.tmp $@

%.service-api-verified:
	perl ${PERL_DOC_INC} -T -e "use PVE::Service::$*; PVE::Service::$*->verify_api();"
	touch $@

%.api-verified:
	perl ${PERL_DOC_INC} -T -e "use PVE::CLI::$*; PVE::CLI::$*->verify_api();"
	touch $@

%-plain.html: %.adoc ${PVE_COMMON_DOC_SOURCES}
	${ASCIIDOC_PVE} compile-wiki -o $@ $*.adoc

chapter-%.html: %.adoc ${PVE_COMMON_DOC_SOURCES}
	${ASCIIDOC_PVE} compile-chapter -o $@ $*.adoc

%.1: %.adoc %.1-synopsis.adoc ${PVE_COMMON_DOC_SOURCES}
	${ASCIIDOC_PVE} compile-man -o $@ $*.adoc
	test -z "$${PVE_DOC_INSTANTVIEW}" || man -l $@

%.1.html: %.adoc %.1-synopsis.adoc ${PVE_COMMON_DOC_SOURCES}
	${ASCIIDOC_PVE} compile-man-html -o $@ $*.adoc

%.8: %.adoc %.8-synopsis.adoc ${PVE_COMMON_DOC_SOURCES}
	${ASCIIDOC_PVE} compile-man -o $@ $*.adoc
	test -z "$${PVE_DOC_INSTANTVIEW}" || man -l $@

%.8.html: %.adoc %.8-synopsis.adoc ${PVE_COMMON_DOC_SOURCES}
	${ASCIIDOC_PVE} compile-man-html -o $@ $*.adoc

%.5: %.adoc %.5-opts.adoc ${PVE_COMMON_DOC_SOURCES}
	${ASCIIDOC_PVE} compile-man -o $@ $*.adoc
	test -z "$${PVE_DOC_INSTANTVIEW}" || man -l $@

%.5.html: %.adoc %.5-opts.adoc ${PVE_COMMON_DOC_SOURCES}
	${ASCIIDOC_PVE} compile-man-html -o $@ $*.adoc

%.5-plain.html: %.adoc %.5-opts.adoc ${PVE_COMMON_DOC_SOURCES}
	${ASCIIDOC_PVE} compile-man-wiki -o $@ $*.adoc


.PHONY: cleanup-docgen
cleanup-docgen:
	rm -f *.xml.tmp *.1 *.5 *.8 *.adoc docinfo.xml
CHAPTER_LIST = \
	chapter-ha-manager.html \
	chapter-notifications.html \
	chapter-pct.html \
	chapter-pmxcfs.html \
	chapter-pve-bibliography.html \
	chapter-pve-faq.html \
	chapter-pve-firewall.html \
	chapter-pve-gui.html \
	chapter-pve-installation.html \
	chapter-pveceph.html \
	chapter-pvecm.html \
	chapter-pvesdn.html \
	chapter-pvesh.html \
	chapter-pvesm.html \
	chapter-pvesr.html \
	chapter-pveum.html \
	chapter-qm.html \
	chapter-qmeventd.html \
	chapter-sysadmin.html \
	chapter-vzdump.html \
	pve-admin-guide.html

CPU_MODELS_CONF_ADOCDEPENDS = \
	${CPU_MODELS_CONF_ADOCSOURCES} \
	cpu-models.conf.5-opts.adoc

CPU_MODELS_CONF_ADOCSOURCES = \
	cpu-models.conf.adoc \
	pve-copyright.adoc

DATACENTER_CFG_ADOCDEPENDS = \
	${DATACENTER_CFG_ADOCSOURCES} \
	datacenter.cfg.5-opts.adoc

DATACENTER_CFG_ADOCSOURCES = \
	datacenter.cfg.adoc \
	pve-copyright.adoc

GFDL_ADOCDEPENDS = \
	${GFDL_ADOCSOURCES}

GFDL_ADOCSOURCES = \
	GFDL.adoc \
	LICENSE

HA_MANAGER_ADOCDEPENDS = \
	${HA_MANAGER_ADOCSOURCES} \
	ha-groups-opts.adoc \
	ha-manager.1-synopsis.adoc \
	ha-resources-opts.adoc

HA_MANAGER_ADOCSOURCES = \
	ha-manager.adoc \
	pve-copyright.adoc

INDEX_ADOCDEPENDS = \
	${INDEX_ADOCSOURCES}

INDEX_ADOCSOURCES = \
	chapter-index-table.adoc \
	index.adoc \
	man1-index-table.adoc \
	man5-index-table.adoc \
	man8-index-table.adoc

MANUAL_PAGES = \
	cpu-models.conf.5 \
	datacenter.cfg.5 \
	ha-manager.1 \
	pct.1 \
	pct.conf.5 \
	pmxcfs.8 \
	pve-firewall.8 \
	pve-ha-crm.8 \
	pve-ha-lrm.8 \
	pveam.1 \
	pveceph.1 \
	pvecm.1 \
	pvedaemon.8 \
	pvenode.1 \
	pveperf.1 \
	pveproxy.8 \
	pvescheduler.8 \
	pvesh.1 \
	pvesm.1 \
	pvesr.1 \
	pvestatd.8 \
	pvesubscription.1 \
	pveum.1 \
	qm.1 \
	qm.conf.5 \
	qmeventd.8 \
	qmrestore.1 \
	spiceproxy.8 \
	vzdump.1

MANUAL_SOURCES = \
	cpu-models.conf.adoc \
	datacenter.cfg.adoc \
	ha-manager.adoc \
	output-format.adoc \
	pct.adoc \
	pct.conf.adoc \
	pmxcfs.adoc \
	pve-copyright.adoc \
	pve-firewall-macros.adoc \
	pve-firewall.adoc \
	pve-ha-crm.adoc \
	pve-ha-lrm.adoc \
	pve-storage-btrfs.adoc \
	pve-storage-cephfs.adoc \
	pve-storage-cifs.adoc \
	pve-storage-dir.adoc \
	pve-storage-glusterfs.adoc \
	pve-storage-iscsi.adoc \
	pve-storage-iscsidirect.adoc \
	pve-storage-lvm.adoc \
	pve-storage-lvmthin.adoc \
	pve-storage-nfs.adoc \
	pve-storage-pbs.adoc \
	pve-storage-rbd.adoc \
	pve-storage-zfs.adoc \
	pve-storage-zfspool.adoc \
	pveam.adoc \
	pveceph.adoc \
	pvecm.adoc \
	pvedaemon.adoc \
	pvenode.adoc \
	pveperf.adoc \
	pveproxy.adoc \
	pvescheduler.adoc \
	pvesh.adoc \
	pvesm.adoc \
	pvesr.adoc \
	pvestatd.adoc \
	pvesubscription.adoc \
	pveum.adoc \
	qm-cloud-init.adoc \
	qm-pci-passthrough.adoc \
	qm.adoc \
	qm.conf.adoc \
	qmeventd.adoc \
	qmrestore.adoc \
	spiceproxy.adoc \
	vzdump.adoc

OUTPUT_FORMAT_ADOCDEPENDS = \
	${OUTPUT_FORMAT_ADOCSOURCES} \
	output-format-opts.adoc

OUTPUT_FORMAT_ADOCSOURCES = \
	output-format.adoc

PCT_ADOCDEPENDS = \
	${PCT_ADOCSOURCES} \
	pct-mountpoint-opts.adoc \
	pct-network-opts.adoc \
	pct.1-synopsis.adoc \
	pct.conf.5-opts.adoc

PCT_ADOCSOURCES = \
	pct.adoc \
	pve-copyright.adoc

PCT_CONF_ADOCDEPENDS = \
	${PCT_CONF_ADOCSOURCES} \
	pct.conf.5-opts.adoc

PCT_CONF_ADOCSOURCES = \
	pct.conf.adoc \
	pve-copyright.adoc

PMXCFS_ADOCDEPENDS = \
	${PMXCFS_ADOCSOURCES} \
	pmxcfs.8-synopsis.adoc

PMXCFS_ADOCSOURCES = \
	pmxcfs.adoc \
	pve-copyright.adoc

PVEAM_ADOCDEPENDS = \
	${PVEAM_ADOCSOURCES} \
	pveam.1-synopsis.adoc

PVEAM_ADOCSOURCES = \
	pve-copyright.adoc \
	pveam.adoc

PVECEPH_ADOCDEPENDS = \
	${PVECEPH_ADOCSOURCES} \
	pveceph.1-synopsis.adoc

PVECEPH_ADOCSOURCES = \
	pve-copyright.adoc \
	pveceph.adoc

PVECM_ADOCDEPENDS = \
	${PVECM_ADOCSOURCES} \
	pvecm.1-synopsis.adoc

PVECM_ADOCSOURCES = \
	pve-copyright.adoc \
	pvecm.adoc

PVEDAEMON_ADOCDEPENDS = \
	${PVEDAEMON_ADOCSOURCES} \
	pvedaemon.8-synopsis.adoc

PVEDAEMON_ADOCSOURCES = \
	pve-copyright.adoc \
	pvedaemon.adoc

PVENODE_ADOCDEPENDS = \
	${PVENODE_ADOCSOURCES} \
	output-format-opts.adoc \
	pvenode.1-synopsis.adoc

PVENODE_ADOCSOURCES = \
	output-format.adoc \
	pve-copyright.adoc \
	pvenode.adoc

PVEPERF_ADOCDEPENDS = \
	${PVEPERF_ADOCSOURCES} \
	pveperf.1-synopsis.adoc

PVEPERF_ADOCSOURCES = \
	pveperf.adoc

PVEPROXY_ADOCDEPENDS = \
	${PVEPROXY_ADOCSOURCES} \
	pveproxy.8-synopsis.adoc

PVEPROXY_ADOCSOURCES = \
	pve-copyright.adoc \
	pveproxy.adoc

PVESCHEDULER_ADOCDEPENDS = \
	${PVESCHEDULER_ADOCSOURCES} \
	pvescheduler.8-synopsis.adoc

PVESCHEDULER_ADOCSOURCES = \
	pve-copyright.adoc \
	pvescheduler.adoc

PVESH_ADOCDEPENDS = \
	${PVESH_ADOCSOURCES} \
	output-format-opts.adoc \
	pvesh.1-synopsis.adoc

PVESH_ADOCSOURCES = \
	output-format.adoc \
	pve-copyright.adoc \
	pvesh.adoc

PVESM_ADOCDEPENDS = \
	${PVESM_ADOCSOURCES} \
	pvesm.1-synopsis.adoc

PVESM_ADOCSOURCES = \
	pve-copyright.adoc \
	pve-storage-btrfs.adoc \
	pve-storage-cephfs.adoc \
	pve-storage-cifs.adoc \
	pve-storage-dir.adoc \
	pve-storage-glusterfs.adoc \
	pve-storage-iscsi.adoc \
	pve-storage-iscsidirect.adoc \
	pve-storage-lvm.adoc \
	pve-storage-lvmthin.adoc \
	pve-storage-nfs.adoc \
	pve-storage-pbs.adoc \
	pve-storage-rbd.adoc \
	pve-storage-zfs.adoc \
	pve-storage-zfspool.adoc \
	pvesm.adoc

PVESR_ADOCDEPENDS = \
	${PVESR_ADOCSOURCES} \
	pvesr.1-synopsis.adoc

PVESR_ADOCSOURCES = \
	pve-copyright.adoc \
	pvesr.adoc

PVESTATD_ADOCDEPENDS = \
	${PVESTATD_ADOCSOURCES} \
	pvestatd.8-synopsis.adoc

PVESTATD_ADOCSOURCES = \
	pve-copyright.adoc \
	pvestatd.adoc

PVESUBSCRIPTION_ADOCDEPENDS = \
	${PVESUBSCRIPTION_ADOCSOURCES} \
	pvesubscription.1-synopsis.adoc

PVESUBSCRIPTION_ADOCSOURCES = \
	pve-copyright.adoc \
	pvesubscription.adoc

PVEUM_ADOCDEPENDS = \
	${PVEUM_ADOCSOURCES} \
	pveum.1-synopsis.adoc

PVEUM_ADOCSOURCES = \
	pve-copyright.adoc \
	pveum.adoc

PVE_ADMIN_GUIDE_ADOCDEPENDS = \
	${PVE_ADMIN_GUIDE_ADOCSOURCES} \
	datacenter.cfg.5-opts.adoc \
	ha-groups-opts.adoc \
	ha-manager.1-synopsis.adoc \
	ha-resources-opts.adoc \
	output-format-opts.adoc \
	pct-mountpoint-opts.adoc \
	pct-network-opts.adoc \
	pct.1-synopsis.adoc \
	pct.conf.5-opts.adoc \
	pmxcfs.8-synopsis.adoc \
	pve-firewall-cluster-opts.adoc \
	pve-firewall-host-opts.adoc \
	pve-firewall-rules-opts.adoc \
	pve-firewall-vm-opts.adoc \
	pve-firewall.8-synopsis.adoc \
	pve-ha-crm.8-synopsis.adoc \
	pve-ha-lrm.8-synopsis.adoc \
	pveam.1-synopsis.adoc \
	pveceph.1-synopsis.adoc \
	pvecm.1-synopsis.adoc \
	pvedaemon.8-synopsis.adoc \
	pvenode.1-synopsis.adoc \
	pveperf.1-synopsis.adoc \
	pveproxy.8-synopsis.adoc \
	pvescheduler.8-synopsis.adoc \
	pvesh.1-synopsis.adoc \
	pvesm.1-synopsis.adoc \
	pvesr.1-synopsis.adoc \
	pvestatd.8-synopsis.adoc \
	pvesubscription.1-synopsis.adoc \
	pveum.1-synopsis.adoc \
	qm-cloud-init-opts.adoc \
	qm.1-synopsis.adoc \
	qm.conf.5-opts.adoc \
	qmrestore.1-synopsis.adoc \
	spiceproxy.8-synopsis.adoc \
	vzdump.1-synopsis.adoc \
	vzdump.conf.5-opts.adoc

PVE_ADMIN_GUIDE_ADOCSOURCES = \
	GFDL.adoc \
	LICENSE \
	calendar-events.adoc \
	certificate-management.adoc \
	datacenter.cfg.adoc \
	getting-help.adoc \
	ha-manager.adoc \
	howto-improve-pve-docs.adoc \
	hyper-converged-infrastructure.adoc \
	kernel-samepage-merging.adoc \
	local-btrfs.adoc \
	local-lvm.adoc \
	local-zfs.adoc \
	markdown-primer.adoc \
	notifications.adoc \
	output-format.adoc \
	pct.adoc \
	pmxcfs.adoc \
	pve-admin-guide.adoc \
	pve-bibliography.adoc \
	pve-disk-health-monitoring.adoc \
	pve-external-metric-server.adoc \
	pve-faq.adoc \
	pve-firewall-macros.adoc \
	pve-firewall.adoc \
	pve-gui.adoc \
	pve-installation-media.adoc \
	pve-installation.adoc \
	pve-intro.adoc \
	pve-network.adoc \
	pve-package-repos.adoc \
	pve-storage-btrfs.adoc \
	pve-storage-cephfs.adoc \
	pve-storage-cifs.adoc \
	pve-storage-dir.adoc \
	pve-storage-glusterfs.adoc \
	pve-storage-iscsi.adoc \
	pve-storage-iscsidirect.adoc \
	pve-storage-lvm.adoc \
	pve-storage-lvmthin.adoc \
	pve-storage-nfs.adoc \
	pve-storage-pbs.adoc \
	pve-storage-rbd.adoc \
	pve-storage-zfs.adoc \
	pve-storage-zfspool.adoc \
	pve-system-requirements.adoc \
	pveceph.adoc \
	pvecm.adoc \
	pvedaemon.adoc \
	pvenode.adoc \
	pveperf.adoc \
	pveproxy.adoc \
	pvescheduler.adoc \
	pvesdn.adoc \
	pvesh.adoc \
	pvesm.adoc \
	pvesr.adoc \
	pvestatd.adoc \
	pvesubscription.adoc \
	pveum.adoc \
	qm-cloud-init.adoc \
	qm-pci-passthrough.adoc \
	qm-vcpu-list.adoc \
	qm.adoc \
	spiceproxy.adoc \
	sysadmin.adoc \
	system-booting.adoc \
	system-software-updates.adoc \
	system-timesync.adoc \
	translation.adoc \
	vzdump.adoc

PVE_FIREWALL_ADOCDEPENDS = \
	${PVE_FIREWALL_ADOCSOURCES} \
	pve-firewall-cluster-opts.adoc \
	pve-firewall-host-opts.adoc \
	pve-firewall-rules-opts.adoc \
	pve-firewall-vm-opts.adoc \
	pve-firewall.8-synopsis.adoc

PVE_FIREWALL_ADOCSOURCES = \
	pve-copyright.adoc \
	pve-firewall-macros.adoc \
	pve-firewall.adoc

PVE_HA_CRM_ADOCDEPENDS = \
	${PVE_HA_CRM_ADOCSOURCES} \
	pve-ha-crm.8-synopsis.adoc

PVE_HA_CRM_ADOCSOURCES = \
	pve-copyright.adoc \
	pve-ha-crm.adoc

PVE_HA_LRM_ADOCDEPENDS = \
	${PVE_HA_LRM_ADOCSOURCES} \
	pve-ha-lrm.8-synopsis.adoc

PVE_HA_LRM_ADOCSOURCES = \
	pve-copyright.adoc \
	pve-ha-lrm.adoc

PVE_INSTALLATION_ADOCDEPENDS = \
	${PVE_INSTALLATION_ADOCSOURCES}

PVE_INSTALLATION_ADOCSOURCES = \
	pve-installation-media.adoc \
	pve-installation.adoc \
	pve-system-requirements.adoc

PVE_INTRO_ADOCDEPENDS = \
	${PVE_INTRO_ADOCSOURCES}

PVE_INTRO_ADOCSOURCES = \
	getting-help.adoc \
	howto-improve-pve-docs.adoc \
	hyper-converged-infrastructure.adoc \
	pve-intro.adoc \
	translation.adoc

PVE_PACKAGE_REPOS_ADOCDEPENDS = \
	${PVE_PACKAGE_REPOS_ADOCSOURCES}

PVE_PACKAGE_REPOS_ADOCSOURCES = \
	pve-copyright.adoc \
	pve-package-repos.adoc

QMEVENTD_ADOCDEPENDS = \
	${QMEVENTD_ADOCSOURCES} \
	qmeventd.8-synopsis.adoc

QMEVENTD_ADOCSOURCES = \
	pve-copyright.adoc \
	qmeventd.adoc

QMRESTORE_ADOCDEPENDS = \
	${QMRESTORE_ADOCSOURCES} \
	qmrestore.1-synopsis.adoc

QMRESTORE_ADOCSOURCES = \
	pve-copyright.adoc \
	qmrestore.adoc

QM_ADOCDEPENDS = \
	${QM_ADOCSOURCES} \
	qm-cloud-init-opts.adoc \
	qm.1-synopsis.adoc \
	qm.conf.5-opts.adoc

QM_ADOCSOURCES = \
	pve-copyright.adoc \
	qm-cloud-init.adoc \
	qm-pci-passthrough.adoc \
	qm.adoc

QM_CLOUD_INIT_ADOCDEPENDS = \
	${QM_CLOUD_INIT_ADOCSOURCES} \
	qm-cloud-init-opts.adoc

QM_CLOUD_INIT_ADOCSOURCES = \
	qm-cloud-init.adoc

QM_CONF_ADOCDEPENDS = \
	${QM_CONF_ADOCSOURCES} \
	qm.conf.5-opts.adoc

QM_CONF_ADOCSOURCES = \
	pve-copyright.adoc \
	qm.conf.adoc

SPICEPROXY_ADOCDEPENDS = \
	${SPICEPROXY_ADOCSOURCES} \
	spiceproxy.8-synopsis.adoc

SPICEPROXY_ADOCSOURCES = \
	pve-copyright.adoc \
	spiceproxy.adoc

SYSADMIN_ADOCDEPENDS = \
	${SYSADMIN_ADOCSOURCES} \
	output-format-opts.adoc \
	pvenode.1-synopsis.adoc

SYSADMIN_ADOCSOURCES = \
	certificate-management.adoc \
	kernel-samepage-merging.adoc \
	local-btrfs.adoc \
	local-lvm.adoc \
	local-zfs.adoc \
	output-format.adoc \
	pve-copyright.adoc \
	pve-disk-health-monitoring.adoc \
	pve-external-metric-server.adoc \
	pve-network.adoc \
	pve-package-repos.adoc \
	pvenode.adoc \
	sysadmin.adoc \
	system-booting.adoc \
	system-software-updates.adoc \
	system-timesync.adoc

VZDUMP_ADOCDEPENDS = \
	${VZDUMP_ADOCSOURCES} \
	vzdump.1-synopsis.adoc \
	vzdump.conf.5-opts.adoc

VZDUMP_ADOCSOURCES = \
	pve-copyright.adoc \
	vzdump.adoc

WIKI_IMPORTS = \
	certificate-management-plain.html \
	cpu-models.conf.5-plain.html \
	datacenter.cfg.5-plain.html \
	getting-help-plain.html \
	ha-manager-plain.html \
	howto-improve-pve-docs-plain.html \
	hyper-converged-infrastructure-plain.html \
	kernel-samepage-merging-plain.html \
	local-btrfs-plain.html \
	local-lvm-plain.html \
	local-zfs-plain.html \
	notifications-plain.html \
	pct-plain.html \
	pct.conf.5-plain.html \
	pmxcfs-plain.html \
	pve-bibliography-plain.html \
	pve-disk-health-monitoring-plain.html \
	pve-external-metric-server-plain.html \
	pve-faq-plain.html \
	pve-firewall-plain.html \
	pve-gui-plain.html \
	pve-installation-media-plain.html \
	pve-installation-plain.html \
	pve-network-plain.html \
	pve-package-repos-plain.html \
	pve-storage-btrfs-plain.html \
	pve-storage-cephfs-plain.html \
	pve-storage-cifs-plain.html \
	pve-storage-dir-plain.html \
	pve-storage-glusterfs-plain.html \
	pve-storage-iscsi-plain.html \
	pve-storage-iscsidirect-plain.html \
	pve-storage-lvm-plain.html \
	pve-storage-lvmthin-plain.html \
	pve-storage-nfs-plain.html \
	pve-storage-pbs-plain.html \
	pve-storage-rbd-plain.html \
	pve-storage-zfs-plain.html \
	pve-storage-zfspool-plain.html \
	pve-system-requirements-plain.html \
	pveceph-plain.html \
	pvecm-plain.html \
	pvenode-plain.html \
	pvesdn-plain.html \
	pvesh-plain.html \
	pvesm-plain.html \
	pvesr-plain.html \
	pveum-plain.html \
	qm-cloud-init-plain.html \
	qm-pci-passthrough-plain.html \
	qm-plain.html \
	qm.conf.5-plain.html \
	qmeventd-plain.html \
	sysadmin-plain.html \
	system-booting-plain.html \
	system-software-updates-plain.html \
	system-timesync-plain.html \
	translation-plain.html \
	vzdump-plain.html

chapter-ha-manager.html: ${HA_MANAGER_ADOCDEPENDS}

chapter-pct.html: ${PCT_ADOCDEPENDS}

chapter-pmxcfs.html: ${PMXCFS_ADOCDEPENDS}

chapter-pve-firewall.html: ${PVE_FIREWALL_ADOCDEPENDS}

chapter-pve-installation.html: ${PVE_INSTALLATION_ADOCDEPENDS}

chapter-pveceph.html: ${PVECEPH_ADOCDEPENDS}

chapter-pvecm.html: ${PVECM_ADOCDEPENDS}

chapter-pvesh.html: ${PVESH_ADOCDEPENDS}

chapter-pvesm.html: ${PVESM_ADOCDEPENDS}

chapter-pvesr.html: ${PVESR_ADOCDEPENDS}

chapter-pveum.html: ${PVEUM_ADOCDEPENDS}

chapter-qm.html: ${QM_ADOCDEPENDS}

chapter-qmeventd.html: ${QMEVENTD_ADOCDEPENDS}

chapter-sysadmin.html: ${SYSADMIN_ADOCDEPENDS}

chapter-vzdump.html: ${VZDUMP_ADOCDEPENDS}

cpu-models.conf.5: ${CPU_MODELS_CONF_ADOCDEPENDS}

cpu-models.conf.5-plain.html: ${CPU_MODELS_CONF_ADOCDEPENDS}

cpu-models.conf.5.html: ${CPU_MODELS_CONF_ADOCDEPENDS}

datacenter.cfg.5: ${DATACENTER_CFG_ADOCDEPENDS}

datacenter.cfg.5-plain.html: ${DATACENTER_CFG_ADOCDEPENDS}

datacenter.cfg.5.html: ${DATACENTER_CFG_ADOCDEPENDS}

ha-manager-plain.html: ${HA_MANAGER_ADOCDEPENDS}

ha-manager.1: ${HA_MANAGER_ADOCDEPENDS}

ha-manager.1-plain.html: ${HA_MANAGER_ADOCDEPENDS}

ha-manager.1.html: ${HA_MANAGER_ADOCDEPENDS}

pct-plain.html: ${PCT_ADOCDEPENDS}

pct.1: ${PCT_ADOCDEPENDS}

pct.1-plain.html: ${PCT_ADOCDEPENDS}

pct.1.html: ${PCT_ADOCDEPENDS}

pct.conf.5: ${PCT_CONF_ADOCDEPENDS}

pct.conf.5-plain.html: ${PCT_CONF_ADOCDEPENDS}

pct.conf.5.html: ${PCT_CONF_ADOCDEPENDS}

pmxcfs-plain.html: ${PMXCFS_ADOCDEPENDS}

pmxcfs.8: ${PMXCFS_ADOCDEPENDS}

pmxcfs.8-plain.html: ${PMXCFS_ADOCDEPENDS}

pmxcfs.8.html: ${PMXCFS_ADOCDEPENDS}

pve-admin-guide.html: ${PVE_ADMIN_GUIDE_ADOCDEPENDS}

pve-firewall-plain.html: ${PVE_FIREWALL_ADOCDEPENDS}

pve-firewall.8: ${PVE_FIREWALL_ADOCDEPENDS}

pve-firewall.8-plain.html: ${PVE_FIREWALL_ADOCDEPENDS}

pve-firewall.8.html: ${PVE_FIREWALL_ADOCDEPENDS}

pve-ha-crm.8: ${PVE_HA_CRM_ADOCDEPENDS}

pve-ha-crm.8-plain.html: ${PVE_HA_CRM_ADOCDEPENDS}

pve-ha-crm.8.html: ${PVE_HA_CRM_ADOCDEPENDS}

pve-ha-lrm.8: ${PVE_HA_LRM_ADOCDEPENDS}

pve-ha-lrm.8-plain.html: ${PVE_HA_LRM_ADOCDEPENDS}

pve-ha-lrm.8.html: ${PVE_HA_LRM_ADOCDEPENDS}

pve-installation-plain.html: ${PVE_INSTALLATION_ADOCDEPENDS}

pve-package-repos-plain.html: ${PVE_PACKAGE_REPOS_ADOCDEPENDS}

pveam.1: ${PVEAM_ADOCDEPENDS}

pveam.1-plain.html: ${PVEAM_ADOCDEPENDS}

pveam.1.html: ${PVEAM_ADOCDEPENDS}

pveceph-plain.html: ${PVECEPH_ADOCDEPENDS}

pveceph.1: ${PVECEPH_ADOCDEPENDS}

pveceph.1-plain.html: ${PVECEPH_ADOCDEPENDS}

pveceph.1.html: ${PVECEPH_ADOCDEPENDS}

pvecm-plain.html: ${PVECM_ADOCDEPENDS}

pvecm.1: ${PVECM_ADOCDEPENDS}

pvecm.1-plain.html: ${PVECM_ADOCDEPENDS}

pvecm.1.html: ${PVECM_ADOCDEPENDS}

pvedaemon.8: ${PVEDAEMON_ADOCDEPENDS}

pvedaemon.8-plain.html: ${PVEDAEMON_ADOCDEPENDS}

pvedaemon.8.html: ${PVEDAEMON_ADOCDEPENDS}

pvenode-plain.html: ${PVENODE_ADOCDEPENDS}

pvenode.1: ${PVENODE_ADOCDEPENDS}

pvenode.1-plain.html: ${PVENODE_ADOCDEPENDS}

pvenode.1.html: ${PVENODE_ADOCDEPENDS}

pveperf.1: ${PVEPERF_ADOCDEPENDS}

pveperf.1-plain.html: ${PVEPERF_ADOCDEPENDS}

pveperf.1.html: ${PVEPERF_ADOCDEPENDS}

pveproxy.8: ${PVEPROXY_ADOCDEPENDS}

pveproxy.8-plain.html: ${PVEPROXY_ADOCDEPENDS}

pveproxy.8.html: ${PVEPROXY_ADOCDEPENDS}

pvescheduler.8: ${PVESCHEDULER_ADOCDEPENDS}

pvescheduler.8-plain.html: ${PVESCHEDULER_ADOCDEPENDS}

pvescheduler.8.html: ${PVESCHEDULER_ADOCDEPENDS}

pvesh-plain.html: ${PVESH_ADOCDEPENDS}

pvesh.1: ${PVESH_ADOCDEPENDS}

pvesh.1-plain.html: ${PVESH_ADOCDEPENDS}

pvesh.1.html: ${PVESH_ADOCDEPENDS}

pvesm-plain.html: ${PVESM_ADOCDEPENDS}

pvesm.1: ${PVESM_ADOCDEPENDS}

pvesm.1-plain.html: ${PVESM_ADOCDEPENDS}

pvesm.1.html: ${PVESM_ADOCDEPENDS}

pvesr-plain.html: ${PVESR_ADOCDEPENDS}

pvesr.1: ${PVESR_ADOCDEPENDS}

pvesr.1-plain.html: ${PVESR_ADOCDEPENDS}

pvesr.1.html: ${PVESR_ADOCDEPENDS}

pvestatd.8: ${PVESTATD_ADOCDEPENDS}

pvestatd.8-plain.html: ${PVESTATD_ADOCDEPENDS}

pvestatd.8.html: ${PVESTATD_ADOCDEPENDS}

pvesubscription.1: ${PVESUBSCRIPTION_ADOCDEPENDS}

pvesubscription.1-plain.html: ${PVESUBSCRIPTION_ADOCDEPENDS}

pvesubscription.1.html: ${PVESUBSCRIPTION_ADOCDEPENDS}

pveum-plain.html: ${PVEUM_ADOCDEPENDS}

pveum.1: ${PVEUM_ADOCDEPENDS}

pveum.1-plain.html: ${PVEUM_ADOCDEPENDS}

pveum.1.html: ${PVEUM_ADOCDEPENDS}

qm-cloud-init-plain.html: ${QM_CLOUD_INIT_ADOCDEPENDS}

qm-plain.html: ${QM_ADOCDEPENDS}

qm.1: ${QM_ADOCDEPENDS}

qm.1-plain.html: ${QM_ADOCDEPENDS}

qm.1.html: ${QM_ADOCDEPENDS}

qm.conf.5: ${QM_CONF_ADOCDEPENDS}

qm.conf.5-plain.html: ${QM_CONF_ADOCDEPENDS}

qm.conf.5.html: ${QM_CONF_ADOCDEPENDS}

qmeventd-plain.html: ${QMEVENTD_ADOCDEPENDS}

qmeventd.8: ${QMEVENTD_ADOCDEPENDS}

qmeventd.8-plain.html: ${QMEVENTD_ADOCDEPENDS}

qmeventd.8.html: ${QMEVENTD_ADOCDEPENDS}

qmrestore.1: ${QMRESTORE_ADOCDEPENDS}

qmrestore.1-plain.html: ${QMRESTORE_ADOCDEPENDS}

qmrestore.1.html: ${QMRESTORE_ADOCDEPENDS}

spiceproxy.8: ${SPICEPROXY_ADOCDEPENDS}

spiceproxy.8-plain.html: ${SPICEPROXY_ADOCDEPENDS}

spiceproxy.8.html: ${SPICEPROXY_ADOCDEPENDS}

sysadmin-plain.html: ${SYSADMIN_ADOCDEPENDS}

vzdump-plain.html: ${VZDUMP_ADOCDEPENDS}

vzdump.1: ${VZDUMP_ADOCDEPENDS}

vzdump.1-plain.html: ${VZDUMP_ADOCDEPENDS}

vzdump.1.html: ${VZDUMP_ADOCDEPENDS}

